==> haskell-http-client-0.5.13.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.13.1
id: http-client-0.5.13.1-AxqHawpHAi6G9sCahIr2Ut
key: http-client-0.5.13.1-AxqHawpHAi6G9sCahIr2Ut
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
abi: f15ab007ad62b4933d2c220fc35cd94b
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure Data.KeyedPool
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-client-0.5.13.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-client-0.5.13.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-client-0.5.13.1
hs-libraries: HShttp-client-0.5.13.1-AxqHawpHAi6G9sCahIr2Ut
depends:
    base-4.11.1.0 bytestring-0.10.8.2 text-1.2.3.0
    http-types-0.12.1-Gr2aQVFR6i1F5AWnhgkIyR
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 time-1.8.0.2
    network-2.7.0.2-Epka4Y5CXXTKVbAZSchnya
    streaming-commons-0.2.1.0-84PfpZMVlC4E4a4Nixx0Ze
    containers-0.5.11.0 transformers-0.5.5.0 deepseq-1.4.3.0
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    exceptions-0.10.0-7FqenMMTX3xHtUICKpGQUY array-0.5.2.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV filepath-1.4.2
    mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4 ghc-prim-0.5.2.0
    stm-2.4.5.0 network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             http-types-0.12.1-Gr2aQVFR6i1F5AWnhgkIyR=434719f760c972f4cce02eab4b258186
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             network-2.7.0.2-Epka4Y5CXXTKVbAZSchnya=34c8f87548d66d5af3596a33ad5000fc
             streaming-commons-0.2.1.0-84PfpZMVlC4E4a4Nixx0Ze=2026f628cce6481a9499bf33e07bf2a6
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=23a2e2ee61129c4073d4aeb70df9c169
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=0526158ceb7aa285fbb07f1a82b14796
             exceptions-0.10.0-7FqenMMTX3xHtUICKpGQUY=1e7acabe11915a69b3faf108407a56c7
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4=6260d9a08ca2b5415d71a41584891d7f
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.5.13.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.13.1
id: http-client-0.5.13.1-JDm4XMYW3FYKJGxcCXzxnq
key: http-client-0.5.13.1-JDm4XMYW3FYKJGxcCXzxnq
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
abi: 0041e3e8498ca1161703d3b32793f2cd
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure Data.KeyedPool
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-client-0.5.13.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-client-0.5.13.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-client-0.5.13.1
hs-libraries: HShttp-client-0.5.13.1-JDm4XMYW3FYKJGxcCXzxnq
depends:
    base-4.11.1.0 bytestring-0.10.8.2 text-1.2.3.0
    http-types-0.12.1-4zLRDB0jdcBCRNesAiQNOR
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 time-1.8.0.2
    network-2.7.0.2-2ShKE4Ejgp6Bq9Qkb7AIP
    streaming-commons-0.2.1.0-6HKlnCd2Opt1lJQzk9xRk4
    containers-0.5.11.0 transformers-0.5.5.0 deepseq-1.4.3.0
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8 array-0.5.2.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV filepath-1.4.2
    mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4 ghc-prim-0.5.2.0
    stm-2.4.5.0 network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             http-types-0.12.1-4zLRDB0jdcBCRNesAiQNOR=65d300d87ffbc99ff3de8ae12198664c
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             network-2.7.0.2-2ShKE4Ejgp6Bq9Qkb7AIP=febca036f4f0db50e6534d133a8b12c8
             streaming-commons-0.2.1.0-6HKlnCd2Opt1lJQzk9xRk4=46d6f6156e7d33f539a6457102dec57d
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=23a2e2ee61129c4073d4aeb70df9c169
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=0526158ceb7aa285fbb07f1a82b14796
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4=6260d9a08ca2b5415d71a41584891d7f
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
